svn commit: samba r2029 - branches/SAMBA_4_0/source/librpc/rpc

tridge at samba.org tridge at samba.org
Tue Aug 24 23:56:59 GMT 2004


Author: tridge
Date: 2004-08-24 23:56:59 +0000 (Tue, 24 Aug 2004)
New Revision: 2029

WebSVN: http://websvn.samba.org/websvn/changeset.php?rep=samba&path=/&rev=2029&nolog=1

Log:
changed our client side dcerpc padding to match what w2k3 does - a 16
byte padding of the payload portion of the packet.


Modified:
   branches/SAMBA_4_0/source/librpc/rpc/dcerpc.c


Changeset:
Modified: branches/SAMBA_4_0/source/librpc/rpc/dcerpc.c
===================================================================
--- branches/SAMBA_4_0/source/librpc/rpc/dcerpc.c	2004-08-24 23:36:37 UTC (rev 2028)
+++ branches/SAMBA_4_0/source/librpc/rpc/dcerpc.c	2004-08-24 23:56:59 UTC (rev 2029)
@@ -245,8 +245,10 @@
 		return status;
 	}
 
-	/* pad to 8 byte multiple */
-	p->security_state.auth_info->auth_pad_length = NDR_ALIGN(ndr, 8);
+	/* pad to 16 byte multiple in the payload portion of the
+	   packet. This matches what w2k3 does */
+	p->security_state.auth_info->auth_pad_length = 
+		(16 - (pkt->u.request.stub_and_verifier.length & 15)) & 15;
 	ndr_push_zero(ndr, p->security_state.auth_info->auth_pad_length);
 
 	/* sign or seal the packet */



More information about the samba-cvs mailing list